@@ -18,7 +18,7 @@ use base qw(Exporter);
 
 our @EXPORT_OK = ();
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 #{{{sub new
 
@@ -114,7 +114,7 @@ sub add_from_file {
                     for ( my $i = 1 ; $i < $number_of_columns ; $i++ ) {
                         my $heading = $column_headings[$i];
                         my $data    = $columns[$i];
-                        my $value   = "$heading = $data";
+                        my $value   = "$heading=$data";
                         push @properties, $value;
                     }
                     $group->add( $id, \@properties );
@@ -287,19 +287,27 @@ sub member_exists {
     if ($success) {
         my $group_info = from_json( ${$res}->content );
         my $is_member  = 0;
-        foreach my $member ( @{ $group_info->{'members'} } ) {
-            if (   $member eq "/system/userManager/user/$exists_member"
-                || $member eq "/system/userManager/group/$exists_member" )
-            {
-                $is_member = 1;
-                last;
+        if ( defined $group_info->{'members'} ) {
+            foreach my $member ( @{ $group_info->{'members'} } ) {
+                if (   $member eq "/system/userManager/user/$exists_member"
+                    || $member eq "/system/userManager/group/$exists_member"
+                    || $member eq "$exists_member" )
+                {
+                    $is_member = 1;
+                    last;
+                }
             }
+            $success = $is_member;
+            $message =
+                "\"$exists_member\" is "
+              . ( $is_member ? q{} : 'not ' )
+              . "a member of group \"$act_on_group\"";
+        }
+        else {
+
+            # members field not defined in JSON:
+            $message = "Problem viewing group members: \"$act_on_group\"";
         }
-        $success = $is_member;
-        $message =
-            "\"$exists_member\" is "
-          . ( $is_member ? q{} : 'not ' )
-          . "a member of group \"$act_on_group\"";
     }
     else {
         $message = "Problem viewing group: \"$act_on_group\"";
@@ -322,16 +330,26 @@ sub member_view {
     my $success = Apache::Sling::GroupUtil::view_eval($res);
     my $message;
     if ($success) {
-        my $group_info     = from_json( ${$res}->content );
-        my $number_members = @{ $group_info->{'members'} };
-        my $members = "Group \"$act_on_group\" has $number_members member(s):";
-        foreach my $member ( @{ $group_info->{'members'} } ) {
-            $members .= "\n$member";
+        my $group_info = from_json( ${$res}->content );
+        if ( defined $group_info->{'members'} ) {
+            my $number_members = @{ $group_info->{'members'} };
+            my $members =
+              "Group \"$act_on_group\" has $number_members member(s):";
+            foreach my $member ( @{ $group_info->{'members'} } ) {
+                $members .= "\n$member";
+            }
+            $message = "$members";
+            $success = $number_members;
+        }
+        else {
+
+            # members field not defined in JSON:
+            $message = "Problem viewing group members: \"$act_on_group\"";
         }
-        $message = "$members";
-        $success = $number_members;
     }
     else {
+
+        # HTTP request did not complete successfully!
         $message = "Problem viewing group: \"$act_on_group\"";
     }
     $group->set_results( "$message", $res );
